tlslite.errors.TLSError

Package tlslite :: Module errors :: Class TLSError |
[show private | hide private]
[frames | no frames]

## Class TLSError

    Exception --+
                |
               TLSError

Known Subclasses:
  `TLSAbruptCloseError`, `TLSAlert`, `TLSAuthenticationError`, `TLSFaultError`

Base class for all TLS Lite exceptions.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net